@@ -4,6 +4,7 @@
  *
  */
 
+#include <stdlib.h>
 
 #include "utils.h"
 
@@ -15,7 +16,6 @@
 #include <QDBusInterface>
 #include <QDBusConnection>
 #include <QDesktopServices>
-//#include <QAbstractKineticScroller>
 
 //#define CAMERA
 
@@ -44,25 +44,55 @@ protected:
     	else {
     		if (!isLabel) {
     			if (f->type == TYPE_PHONE_NUMBER) {
-//    				QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
-//    				QDBusInterface dbusPhone( "com.nokia.csd.Call", "/com/nokia/csd/call", "com.nokia.csd.Call", conn );
-//    				QDBusMessage msg = dbusPhone.call( "CreateWith", f->value, (uint)0 );
+//    				QSettings settings;
 
-    				QDBusMessage msg = QDBusMessage::createMethodCall(
-    				        "", //"com.nokia.csd.Call", // --dest
-    				        "/com/nokia/csd/call", // destination object path
-    				        "com.nokia.csd.Call", // message name (w/o method)
-    				        "CreateWith" // method
-    				    );
-    				msg << f->value;
-    				msg << 0;
-    				msg = QDBusConnection::systemBus().call(msg);
+    				QString telf = f->value;
+    				telf = telf.simplified();
+    				telf = telf.replace(" ", "");
 
-    				qDebug() << msg;
-/*
-dbus-send --system --type=method_call --print-reply --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:"$NUMBER" uint32:0
+    				if (telf.length() > 0) {
+    					qDebug () << "calling to " << telf;
+						QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
+						QDBusInterface dbusPhone( QString ("com.nokia.csd.Call"), QString ("/com/nokia/csd/call"), QString ("com.nokia.csd.Call"), conn );
+						QDBusMessage msg = dbusPhone.call( QString ("CreateWith"), telf, (uint)0 );
+						qDebug() << msg;
+    				}
 
- */
+//    				if (settings.value("TT/method1").toBool()) {
+//    					qDebug () << "method1";
+//
+//	    				qDebug () << settings.value("TT/dest") << "-" << settings.value("TT/object") << "-" << settings.value("TT/message") << "-" << settings.value("TT/method");
+//
+//	    				QDBusConnection conn = QDBusConnection::systemBus(); //QString(MCE_SERVICE), QString(MCE_SIGNAL_PATH)
+//
+//	    				QDBusInterface dbusPhone( settings.value("TT/dest").toString(), settings.value("TT/object").toString(), settings.value("TT/message").toString(), conn );
+//	    				QDBusMessage msg = dbusPhone.call( settings.value("TT/method").toString(), f->value, (uint)0 );
+//
+//	    				qDebug() << msg;
+//    				}
+//
+//    				if (settings.value("TT/method2").toBool()) {
+//    					qDebug () << "method2";
+//
+//	    				qDebug () << settings.value("TT/dest") << "-" << settings.value("TT/object") << "-" << settings.value("TT/message") << "-" << settings.value("TT/method");
+//
+//						QDBusMessage msg = QDBusMessage::createMethodCall(
+//								settings.value("TT/dest").toString(), //QString ("com.nokia.csd.Call"), // --dest
+//								settings.value("TT/object").toString(), //QString ("/com/nokia/csd/call"), // destination object path
+//								settings.value("TT/message").toString(), //QString ("com.nokia.csd.Call"), // message name (w/o method)
+//								settings.value("TT/method").toString() //QString ("CreateWith") // method
+//							);
+//						msg << f->value;
+//						msg << 0;
+//						msg = QDBusConnection::systemBus().call(msg);
+//						qDebug() << msg;
+//    				}
+//
+//    				if (settings.value("TT/method3").toBool()) {
+//    					qDebug () << "method3";
+//
+//    					::system ((const char *)(QString ("dbus-send --system --type=method_call --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%1\" uint32:0").arg(f->value).constData()));
+//    				}
     			}
     			else {
 #ifdef Q_WS_MAEMO_5
